import React, { useState, useEffect, useContext } from 'react';
import { Route, Redirect, RouteProps } from 'react-router-dom';
import { NonAuthRoutes } from 'api/routes';
import { AuthContext } from 'components/AuthUser/AuthContext';

/**
 * A wrapper for <Route> that redirects to the login screen if you're not yet authenticated.
 * Every non-public route must be wrapped with this component.
 * */
type Props = {
  Component: React.FC<RouteProps>;
  path: string;
  requiredRoles: string[];
};

/* eslint-disable react/jsx-props-no-spreading */
export const PrivateRoute = ({
  Component,
  path,
  requiredRoles,
}: Props): JSX.Element => {
  const { role, isAuth } = useContext(AuthContext);

  // Check if the role is contained in the roles array (passed as props).
  const userHasRequiredRole = requiredRoles.includes(role);

  const message = userHasRequiredRole
    ? 'Please log in to view this page'
    : 'Your role is not allowed';

  return (
    <Route
      exact={false}
      path={path}
      render={(props: RouteProps) =>
        isAuth && userHasRequiredRole ? (
          <Component {...props} />
        ) : (
          <Redirect
            to={{
              pathname: !userHasRequiredRole
                ? `${NonAuthRoutes.auth}${NonAuthRoutes.signIn}`
                : NonAuthRoutes.unauthorized,
              state: {
                message,
                requestedPath: path,
              },
            }}
          />
        )
      }
    />
  );
};
